# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0042_stats_rec import V0042StatsRec


class TestV0042StatsRec(unittest.TestCase):
    """V0042StatsRec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0042StatsRec:
        """Test V0042StatsRec
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0042StatsRec`
        """
        model = V0042StatsRec()
        if include_optional:
            return V0042StatsRec(
                time_start = 56,
                rollups = slurmrestpy.models.v0/0/42_rollup_stats.v0.0.42_rollup_stats(
                    hourly = slurmrestpy.models.v0_0_42_rollup_stats_hourly.v0_0_42_rollup_stats_hourly(
                        count = 56,
                        last_run = 56,
                        duration = slurmrestpy.models.v0_0_42_rollup_stats_hourly_duration.v0_0_42_rollup_stats_hourly_duration(
                            last = 56,
                            max = 56,
                            time = 56, ), ),
                    daily = slurmrestpy.models.v0_0_42_rollup_stats_daily.v0_0_42_rollup_stats_daily(
                        count = 56,
                        last_run = 56, ),
                    monthly = slurmrestpy.models.v0_0_42_rollup_stats_monthly.v0_0_42_rollup_stats_monthly(
                        count = 56,
                        last_run = 56, ), ),
                rpcs = [
                    slurmrestpy.models.v0/0/42_stats_rpc.v0.0.42_stats_rpc(
                        rpc = '',
                        count = 56,
                        time = slurmrestpy.models.v0_0_42_stats_rpc_time.v0_0_42_stats_rpc_time(
                            average = 56,
                            total = 56, ), )
                    ],
                users = [
                    slurmrestpy.models.v0/0/42_stats_user.v0.0.42_stats_user(
                        user = '',
                        count = 56,
                        time = slurmrestpy.models.v0_0_42_stats_rpc_time.v0_0_42_stats_rpc_time(
                            average = 56,
                            total = 56, ), )
                    ]
            )
        else:
            return V0042StatsRec(
        )
        """

    def testV0042StatsRec(self):
        """Test V0042StatsRec"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner import (
    V0041OpenapiJobInfoRespJobsInnerJobResourcesNodesAllocationInner,
)


class TestV0041OpenapiJobInfoRespJobsInnerJobResourcesNodesAllocationInner(
    unittest.TestCase
):
    """V0041OpenapiJobInfoRespJobsInnerJobResourcesNodesAllocationInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(
        self, include_optional
    ) -> V0041OpenapiJobInfoRespJobsInnerJobResourcesNodesAllocationInner:
        """Test V0041OpenapiJobInfoRespJobsInnerJobResourcesNodesAllocationInner
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiJobInfoRespJobsInnerJobResourcesNodesAllocationInner`
        """
        model = V0041OpenapiJobInfoRespJobsInnerJobResourcesNodesAllocationInner()
        if include_optional:
            return V0041OpenapiJobInfoRespJobsInnerJobResourcesNodesAllocationInner(
                index = 56,
                name = '',
                cpus = slurmrestpy.models.v0_0_42_job_res_node_cpus.v0_0_42_job_res_node_cpus(
                    count = 56,
                    used = 56, ),
                memory = slurmrestpy.models.v0_0_42_job_res_node_memory.v0_0_42_job_res_node_memory(
                    used = 56,
                    allocated = 56, ),
                sockets = [
                    slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner_sockets_inner.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner_sockets_inner(
                        index = 56,
                        cores = [
                            slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner_sockets_inner_cores_inner.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner_sockets_inner_cores_inner(
                                index = 56,
                                status = [
                                    'INVALID'
                                    ], )
                            ], )
                    ]
            )
        else:
            return V0041OpenapiJobInfoRespJobsInnerJobResourcesNodesAllocationInner(
                index = 56,
                name = '',
                sockets = [
                    slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner_sockets_inner.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner_sockets_inner(
                        index = 56,
                        cores = [
                            slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner_sockets_inner_cores_inner.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner_sockets_inner_cores_inner(
                                index = 56,
                                status = [
                                    'INVALID'
                                    ], )
                            ], )
                    ],
        )
        """

    def testV0041OpenapiJobInfoRespJobsInnerJobResourcesNodesAllocationInner(self):
        """Test V0041OpenapiJobInfoRespJobsInnerJobResourcesNodesAllocationInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_accounts_add_cond_resp import (
    V0041OpenapiAccountsAddCondResp,
)


class TestV0041OpenapiAccountsAddCondResp(unittest.TestCase):
    """V0041OpenapiAccountsAddCondResp unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0041OpenapiAccountsAddCondResp:
        """Test V0041OpenapiAccountsAddCondResp
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiAccountsAddCondResp`
        """
        model = V0041OpenapiAccountsAddCondResp()
        if include_optional:
            return V0041OpenapiAccountsAddCondResp(
                association_condition = slurmrestpy.models.v0_0_41_openapi_accounts_add_cond_resp_association_condition.v0_0_41_openapi_accounts_add_cond_resp_association_condition(
                    accounts = [
                        ''
                        ],
                    association = slurmrestpy.models.v0_0_41_openapi_users_add_cond_resp_association_condition_association.v0_0_41_openapi_users_add_cond_resp_association_condition_association(
                        comment = '',
                        defaultqos = '',
                        grpjobs = slurmrestpy.models.v0_0_41_openapi_users_add_cond_resp_association_condition_association_grpjobs.v0_0_41_openapi_users_add_cond_resp_association_condition_association_grpjobs(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        grpjobsaccrue = slurmrestpy.models.v0_0_41_openapi_users_add_cond_resp_association_condition_association_grpjobsaccrue.v0_0_41_openapi_users_add_cond_resp_association_condition_association_grpjobsaccrue(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        grpsubmitjobs = slurmrestpy.models.v0_0_41_openapi_users_add_cond_resp_association_condition_association_grpsubmitjobs.v0_0_41_openapi_users_add_cond_resp_association_condition_association_grpsubmitjobs(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        grptres = [
                            slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                                type = '',
                                name = '',
                                id = 56,
                                count = 56, )
                            ],
                        grptresmins = [
                            slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                                type = '',
                                name = '',
                                id = 56,
                                count = 56, )
                            ],
                        grptresrunmins = [

                            ],
                        grpwall = slurmrestpy.models.v0_0_41_openapi_users_add_cond_resp_association_condition_association_grpwall.v0_0_41_openapi_users_add_cond_resp_association_condition_association_grpwall(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        maxjobs = slurmrestpy.models.v0_0_41_openapi_users_add_cond_resp_association_condition_association_maxjobs.v0_0_41_openapi_users_add_cond_resp_association_condition_association_maxjobs(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        maxjobsaccrue = slurmrestpy.models.v0_0_41_openapi_users_add_cond_resp_association_condition_association_maxjobsaccrue.v0_0_41_openapi_users_add_cond_resp_association_condition_association_maxjobsaccrue(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        maxsubmitjobs = slurmrestpy.models.v0_0_41_openapi_users_add_cond_resp_association_condition_association_maxsubmitjobs.v0_0_41_openapi_users_add_cond_resp_association_condition_association_maxsubmitjobs(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        maxtresminsperjob = [

                            ],
                        maxtresrunmins = [

                            ],
                        maxtresperjob = [

                            ],
                        maxtrespernode = [

                            ],
                        maxwalldurationperjob = slurmrestpy.models.v0_0_41_openapi_users_add_cond_resp_association_condition_association_maxwalldurationperjob.v0_0_41_openapi_users_add_cond_resp_association_condition_association_maxwalldurationperjob(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        minpriothresh = slurmrestpy.models.v0_0_41_openapi_users_add_cond_resp_association_condition_association_minpriothresh.v0_0_41_openapi_users_add_cond_resp_association_condition_association_minpriothresh(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        parent = '',
                        priority = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_priority.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_priority(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        qoslevel = [
                            ''
                            ],
                        fairshare = 56, ),
                    clusters = [
                        ''
                        ], ),
                account = slurmrestpy.models.v0_0_41_openapi_accounts_add_cond_resp_account.v0_0_41_openapi_accounts_add_cond_resp_account(
                    description = '',
                    organization = '', ),
                meta = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_meta.v0_0_41_openapi_slurmdbd_jobs_resp_meta(
                    plugin = slurmrestpy.models.v0_0_42_openapi_meta_plugin.v0_0_42_openapi_meta_plugin(
                        type = '',
                        name = '',
                        data_parser = '',
                        accounting_storage = '', ),
                    client = slurmrestpy.models.v0_0_42_openapi_meta_client.v0_0_42_openapi_meta_client(
                        source = '',
                        user = '',
                        group = '', ),
                    command = [
                        ''
                        ],
                    slurm = slurmrestpy.models.v0_0_42_openapi_meta_slurm.v0_0_42_openapi_meta_slurm(
                        version = slurmrestpy.models.v0_0_42_openapi_meta_slurm_version.v0_0_42_openapi_meta_slurm_version(
                            major = '',
                            micro = '',
                            minor = '', ),
                        release = '',
                        cluster = '', ), ),
                errors = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_errors_inner.v0_0_41_openapi_slurmdbd_jobs_resp_errors_inner(
                        description = '',
                        error_number = 56,
                        error = '',
                        source = '', )
                    ],
                warnings = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_warnings_inner.v0_0_41_openapi_slurmdbd_jobs_resp_warnings_inner(
                        description = '',
                        source = '', )
                    ]
            )
        else:
            return V0041OpenapiAccountsAddCondResp(
        )
        """

    def testV0041OpenapiAccountsAddCondResp(self):
        """Test V0041OpenapiAccountsAddCondResp"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_associations_inner_max import (
    V0041OpenapiSlurmdbdConfigRespAssociationsInnerMax,
)


class TestV0041OpenapiSlurmdbdConfigRespAssociationsInnerMax(unittest.TestCase):
    """V0041OpenapiSlurmdbdConfigRespAssociationsInnerMax unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(
        self, include_optional
    ) -> V0041OpenapiSlurmdbdConfigRespAssociationsInnerMax:
        """Test V0041OpenapiSlurmdbdConfigRespAssociationsInnerMax
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiSlurmdbdConfigRespAssociationsInnerMax`
        """
        model = V0041OpenapiSlurmdbdConfigRespAssociationsInnerMax()
        if include_optional:
            return V0041OpenapiSlurmdbdConfigRespAssociationsInnerMax(
                jobs = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs(
                    per = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs_per.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs_per(
                        count = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_count.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_count(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        accruing = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_accruing.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_accruing(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        submitted = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs_per_submitted.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs_per_submitted(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        wall_clock = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_wall_clock_per_job.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_wall_clock_per_job(
                            set = True,
                            infinite = True,
                            number = 56, ), ),
                    active = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs_active.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs_active(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    accruing = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs_accruing.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs_accruing(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    total = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs_total.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs_total(
                        set = True,
                        infinite = True,
                        number = 56, ), ),
                tres = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_tres.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_tres(
                    total = [
                        slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                            type = '',
                            name = '',
                            id = 56,
                            count = 56, )
                        ],
                    group = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_tres_group.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_tres_group(
                        minutes = [
                            slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                                type = '',
                                name = '',
                                id = 56,
                                count = 56, )
                            ],
                        active = [

                            ], ),
                    minutes = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_tres_minutes.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_tres_minutes(
                        per = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_tres_minutes_per.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_tres_minutes_per(
                            job = [

                                ], ), ),
                    per = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_tres_per.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_tres_per(
                        node = [

                            ], ), ),
                per = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_per.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_per(
                    account = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_per_account.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_per_account(
                        wall_clock = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_wall_clock_per_qos.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_wall_clock_per_qos(
                            set = True,
                            infinite = True,
                            number = 56, ), ), )
            )
        else:
            return V0041OpenapiSlurmdbdConfigRespAssociationsInnerMax(
        )
        """

    def testV0041OpenapiSlurmdbdConfigRespAssociationsInnerMax(self):
        """Test V0041OpenapiSlurmdbdConfigRespAssociationsInnerMax"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_minutes import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxTresMinutes,
)


class TestV0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxTresMinutes(unittest.TestCase):
    """V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxTresMinutes unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(
        self, include_optional
    ) -> V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxTresMinutes:
        """Test V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxTresMinutes
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxTresMinutes`
        """
        model = V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxTresMinutes()
        if include_optional:
            return V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxTresMinutes(
                per = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_minutes_per.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_minutes_per(
                    qos = [
                        slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                            type = '',
                            name = '',
                            id = 56,
                            count = 56, )
                        ],
                    job = [
                        slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                            type = '',
                            name = '',
                            id = 56,
                            count = 56, )
                        ],
                    account = [

                        ],
                    user = [

                        ], )
            )
        else:
            return V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxTresMinutes(
        )
        """

    def testV0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxTresMinutes(self):
        """Test V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxTresMinutes"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0042_partition_info_maximums import V0042PartitionInfoMaximums


class TestV0042PartitionInfoMaximums(unittest.TestCase):
    """V0042PartitionInfoMaximums unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0042PartitionInfoMaximums:
        """Test V0042PartitionInfoMaximums
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0042PartitionInfoMaximums`
        """
        model = V0042PartitionInfoMaximums()
        if include_optional:
            return V0042PartitionInfoMaximums(
                cpus_per_node = slurmrestpy.models.v0/0/42_uint32_no_val_struct.v0.0.42_uint32_no_val_struct(
                    set = True,
                    infinite = True,
                    number = 56, ),
                cpus_per_socket = slurmrestpy.models.v0/0/42_uint32_no_val_struct.v0.0.42_uint32_no_val_struct(
                    set = True,
                    infinite = True,
                    number = 56, ),
                memory_per_cpu = 56,
                partition_memory_per_cpu = slurmrestpy.models.v0/0/42_uint64_no_val_struct.v0.0.42_uint64_no_val_struct(
                    set = True,
                    infinite = True,
                    number = 56, ),
                partition_memory_per_node = slurmrestpy.models.v0/0/42_uint64_no_val_struct.v0.0.42_uint64_no_val_struct(
                    set = True,
                    infinite = True,
                    number = 56, ),
                nodes = slurmrestpy.models.v0/0/42_uint32_no_val_struct.v0.0.42_uint32_no_val_struct(
                    set = True,
                    infinite = True,
                    number = 56, ),
                shares = 56,
                oversubscribe = slurmrestpy.models.v0_0_42_partition_info_maximums_oversubscribe.v0_0_42_partition_info_maximums_oversubscribe(
                    jobs = 56,
                    flags = [
                        'force'
                        ], ),
                time = slurmrestpy.models.v0/0/42_uint32_no_val_struct.v0.0.42_uint32_no_val_struct(
                    set = True,
                    infinite = True,
                    number = 56, ),
                over_time_limit = slurmrestpy.models.v0/0/42_uint16_no_val_struct.v0.0.42_uint16_no_val_struct(
                    set = True,
                    infinite = True,
                    number = 56, )
            )
        else:
            return V0042PartitionInfoMaximums(
        )
        """

    def testV0042PartitionInfoMaximums(self):
        """Test V0042PartitionInfoMaximums"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_reservation_resp import (
    V0041OpenapiReservationResp,
)


class TestV0041OpenapiReservationResp(unittest.TestCase):
    """V0041OpenapiReservationResp unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0041OpenapiReservationResp:
        """Test V0041OpenapiReservationResp
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiReservationResp`
        """
        model = V0041OpenapiReservationResp()
        if include_optional:
            return V0041OpenapiReservationResp(
                reservations = [
                    slurmrestpy.models.v0_0_41_openapi_reservation_resp_reservations_inner.v0_0_41_openapi_reservation_resp_reservations_inner(
                        accounts = '',
                        burst_buffer = '',
                        core_count = 56,
                        core_specializations = [
                            slurmrestpy.models.v0_0_41_openapi_reservation_resp_reservations_inner_core_specializations_inner.v0_0_41_openapi_reservation_resp_reservations_inner_core_specializations_inner(
                                node = '',
                                core = '', )
                            ],
                        end_time = slurmrestpy.models.v0_0_41_openapi_reservation_resp_reservations_inner_end_time.v0_0_41_openapi_reservation_resp_reservations_inner_end_time(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        features = '',
                        flags = [
                            'MAINT'
                            ],
                        groups = '',
                        licenses = '',
                        max_start_delay = 56,
                        name = '',
                        node_count = 56,
                        node_list = '',
                        partition = '',
                        purge_completed = slurmrestpy.models.v0_0_41_openapi_reservation_resp_reservations_inner_purge_completed.v0_0_41_openapi_reservation_resp_reservations_inner_purge_completed(
                            time = slurmrestpy.models.v0_0_41_openapi_reservation_resp_reservations_inner_purge_completed_time.v0_0_41_openapi_reservation_resp_reservations_inner_purge_completed_time(
                                set = True,
                                infinite = True,
                                number = 56, ), ),
                        start_time = slurmrestpy.models.v0_0_41_openapi_reservation_resp_reservations_inner_start_time.v0_0_41_openapi_reservation_resp_reservations_inner_start_time(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        watts = slurmrestpy.models.v0_0_41_openapi_reservation_resp_reservations_inner_watts.v0_0_41_openapi_reservation_resp_reservations_inner_watts(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        tres = '',
                        users = '', )
                    ],
                last_update = slurmrestpy.models.v0_0_41_openapi_reservation_resp_last_update.v0_0_41_openapi_reservation_resp_last_update(
                    set = True,
                    infinite = True,
                    number = 56, ),
                meta = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_meta.v0_0_41_openapi_slurmdbd_jobs_resp_meta(
                    plugin = slurmrestpy.models.v0_0_42_openapi_meta_plugin.v0_0_42_openapi_meta_plugin(
                        type = '',
                        name = '',
                        data_parser = '',
                        accounting_storage = '', ),
                    client = slurmrestpy.models.v0_0_42_openapi_meta_client.v0_0_42_openapi_meta_client(
                        source = '',
                        user = '',
                        group = '', ),
                    command = [
                        ''
                        ],
                    slurm = slurmrestpy.models.v0_0_42_openapi_meta_slurm.v0_0_42_openapi_meta_slurm(
                        version = slurmrestpy.models.v0_0_42_openapi_meta_slurm_version.v0_0_42_openapi_meta_slurm_version(
                            major = '',
                            micro = '',
                            minor = '', ),
                        release = '',
                        cluster = '', ), ),
                errors = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_errors_inner.v0_0_41_openapi_slurmdbd_jobs_resp_errors_inner(
                        description = '',
                        error_number = 56,
                        error = '',
                        source = '', )
                    ],
                warnings = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_warnings_inner.v0_0_41_openapi_slurmdbd_jobs_resp_warnings_inner(
                        description = '',
                        source = '', )
                    ]
            )
        else:
            return V0041OpenapiReservationResp(
                reservations = [
                    slurmrestpy.models.v0_0_41_openapi_reservation_resp_reservations_inner.v0_0_41_openapi_reservation_resp_reservations_inner(
                        accounts = '',
                        burst_buffer = '',
                        core_count = 56,
                        core_specializations = [
                            slurmrestpy.models.v0_0_41_openapi_reservation_resp_reservations_inner_core_specializations_inner.v0_0_41_openapi_reservation_resp_reservations_inner_core_specializations_inner(
                                node = '',
                                core = '', )
                            ],
                        end_time = slurmrestpy.models.v0_0_41_openapi_reservation_resp_reservations_inner_end_time.v0_0_41_openapi_reservation_resp_reservations_inner_end_time(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        features = '',
                        flags = [
                            'MAINT'
                            ],
                        groups = '',
                        licenses = '',
                        max_start_delay = 56,
                        name = '',
                        node_count = 56,
                        node_list = '',
                        partition = '',
                        purge_completed = slurmrestpy.models.v0_0_41_openapi_reservation_resp_reservations_inner_purge_completed.v0_0_41_openapi_reservation_resp_reservations_inner_purge_completed(
                            time = slurmrestpy.models.v0_0_41_openapi_reservation_resp_reservations_inner_purge_completed_time.v0_0_41_openapi_reservation_resp_reservations_inner_purge_completed_time(
                                set = True,
                                infinite = True,
                                number = 56, ), ),
                        start_time = slurmrestpy.models.v0_0_41_openapi_reservation_resp_reservations_inner_start_time.v0_0_41_openapi_reservation_resp_reservations_inner_start_time(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        watts = slurmrestpy.models.v0_0_41_openapi_reservation_resp_reservations_inner_watts.v0_0_41_openapi_reservation_resp_reservations_inner_watts(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        tres = '',
                        users = '', )
                    ],
                last_update = slurmrestpy.models.v0_0_41_openapi_reservation_resp_last_update.v0_0_41_openapi_reservation_resp_last_update(
                    set = True,
                    infinite = True,
                    number = 56, ),
        )
        """

    def testV0041OpenapiReservationResp(self):
        """Test V0041OpenapiReservationResp"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_associations_inner import (
    V0041OpenapiSlurmdbdConfigRespAssociationsInner,
)


class TestV0041OpenapiSlurmdbdConfigRespAssociationsInner(unittest.TestCase):
    """V0041OpenapiSlurmdbdConfigRespAssociationsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(
        self, include_optional
    ) -> V0041OpenapiSlurmdbdConfigRespAssociationsInner:
        """Test V0041OpenapiSlurmdbdConfigRespAssociationsInner
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiSlurmdbdConfigRespAssociationsInner`
        """
        model = V0041OpenapiSlurmdbdConfigRespAssociationsInner()
        if include_optional:
            return V0041OpenapiSlurmdbdConfigRespAssociationsInner(
                accounting = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_users_inner_wckeys_inner_accounting_inner.v0_0_41_openapi_slurmdbd_config_resp_users_inner_wckeys_inner_accounting_inner(
                        allocated = slurmrestpy.models.v0_0_40_accounting_allocated.v0_0_40_accounting_allocated(
                            seconds = 56, ),
                        id = 56,
                        start = 56,
                        tres = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_users_inner_wckeys_inner_accounting_inner_tres.v0_0_41_openapi_slurmdbd_config_resp_users_inner_wckeys_inner_accounting_inner_TRES(
                            type = '',
                            name = '',
                            id = 56,
                            count = 56, ), )
                    ],
                account = '',
                cluster = '',
                comment = '',
                default = slurmrestpy.models.v0_0_42_assoc_default.v0_0_42_assoc_default(
                    qos = '', ),
                flags = [
                    'DELETED'
                    ],
                max = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max(
                    jobs = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs(
                        per = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs_per.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs_per(
                            count = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_count.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_count(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            accruing = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_accruing.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_accruing(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            submitted = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs_per_submitted.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs_per_submitted(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            wall_clock = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_wall_clock_per_job.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_wall_clock_per_job(
                                set = True,
                                infinite = True,
                                number = 56, ), ),
                        active = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs_active.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs_active(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        accruing = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs_accruing.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs_accruing(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        total = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs_total.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs_total(
                            set = True,
                            infinite = True,
                            number = 56, ), ),
                    tres = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_tres.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_tres(
                        group = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_tres_group.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_tres_group(
                            minutes = [
                                slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                                    type = '',
                                    name = '',
                                    id = 56, )
                                ], ),
                        minutes = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_tres_minutes.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_tres_minutes(), ),
                    per = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_per.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_per(
                        account = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_per_account.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_per_account(), ), ),
                id = 56,
                is_default = True,
                lineage = '',
                min = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_min.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_min(
                    priority_threshold = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_min_priority_threshold.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_min_priority_threshold(
                        set = True,
                        infinite = True,
                        number = 56, ), ),
                parent_account = '',
                partition = '',
                priority = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_priority.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_priority(
                    set = True,
                    infinite = True,
                    number = 56, ),
                qos = [
                    ''
                    ],
                shares_raw = 56,
                user = ''
            )
        else:
            return V0041OpenapiSlurmdbdConfigRespAssociationsInner(
                user = '',
        )
        """

    def testV0041OpenapiSlurmdbdConfigRespAssociationsInner(self):
        """Test V0041OpenapiSlurmdbdConfigRespAssociationsInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set, Union

from pydantic import (
    BaseModel,
    ConfigDict,
    Field,
    StrictFloat,
    StrictInt,
    StrictStr,
    field_validator,
)
from typing_extensions import Self

from slurmrestpy.models.v0042_acct_gather_energy import V0042AcctGatherEnergy
from slurmrestpy.models.v0042_uint64_no_val_struct import V0042Uint64NoValStruct


class V0042Node(BaseModel):
    """
    V0042Node
    """  # noqa: E501

    architecture: Optional[StrictStr] = Field(
        default=None, description="Computer architecture"
    )
    burstbuffer_network_address: Optional[StrictStr] = Field(
        default=None,
        description="Alternate network path to be used for sbcast network traffic",
    )
    boards: Optional[StrictInt] = Field(
        default=None,
        description="Number of Baseboards in nodes with a baseboard controller",
    )
    boot_time: Optional[V0042Uint64NoValStruct] = None
    cluster_name: Optional[StrictStr] = Field(
        default=None, description="Cluster name (only set in federated environments)"
    )
    cores: Optional[StrictInt] = Field(
        default=None,
        description="Number of cores in a single physical processor socket",
    )
    specialized_cores: Optional[StrictInt] = Field(
        default=None, description="Number of cores reserved for system use"
    )
    cpu_binding: Optional[StrictInt] = Field(
        default=None, description="Default method for binding tasks to allocated CPUs"
    )
    cpu_load: Optional[StrictInt] = Field(
        default=None, description="CPU load as reported by the OS"
    )
    free_mem: Optional[V0042Uint64NoValStruct] = None
    cpus: Optional[StrictInt] = Field(
        default=None, description="Total CPUs, including cores and threads"
    )
    effective_cpus: Optional[StrictInt] = Field(
        default=None,
        description="Number of effective CPUs (excluding specialized CPUs)",
    )
    specialized_cpus: Optional[StrictStr] = Field(
        default=None,
        description="Abstract CPU IDs on this node reserved for exclusive use by slurmd and slurmstepd",
    )
    energy: Optional[V0042AcctGatherEnergy] = None
    external_sensors: Optional[Dict[str, Any]] = None
    extra: Optional[StrictStr] = Field(
        default=None,
        description="Arbitrary string used for node filtering if extra constraints are enabled",
    )
    power: Optional[Dict[str, Any]] = None
    features: Optional[List[StrictStr]] = None
    active_features: Optional[List[StrictStr]] = None
    gpu_spec: Optional[StrictStr] = Field(
        default=None, description="CPU cores reserved for jobs that also use a GPU"
    )
    gres: Optional[StrictStr] = Field(default=None, description="Generic resources")
    gres_drained: Optional[StrictStr] = Field(
        default=None, description="Drained generic resources"
    )
    gres_used: Optional[StrictStr] = Field(
        default=None, description="Generic resources currently in use"
    )
    instance_id: Optional[StrictStr] = Field(
        default=None, description="Cloud instance ID"
    )
    instance_type: Optional[StrictStr] = Field(
        default=None, description="Cloud instance type"
    )
    last_busy: Optional[V0042Uint64NoValStruct] = None
    mcs_label: Optional[StrictStr] = Field(
        default=None, description="Multi-Category Security label"
    )
    specialized_memory: Optional[StrictInt] = Field(
        default=None,
        description="Combined memory limit, in MB, for Slurm compute node daemons",
    )
    name: Optional[StrictStr] = Field(default=None, description="NodeName")
    next_state_after_reboot: Optional[List[StrictStr]] = None
    address: Optional[StrictStr] = Field(
        default=None, description="NodeAddr, used to establish a communication path"
    )
    hostname: Optional[StrictStr] = Field(default=None, description="NodeHostname")
    state: Optional[List[StrictStr]] = None
    operating_system: Optional[StrictStr] = Field(
        default=None, description="Operating system reported by the node"
    )
    owner: Optional[StrictStr] = Field(
        default=None,
        description="User allowed to run jobs on this node (unset if no restriction)",
    )
    partitions: Optional[List[StrictStr]] = None
    port: Optional[StrictInt] = Field(
        default=None, description="TCP port number of the slurmd"
    )
    real_memory: Optional[StrictInt] = Field(
        default=None, description="Total memory in MB on the node"
    )
    res_cores_per_gpu: Optional[StrictInt] = Field(
        default=None, description="Number of CPU cores per GPU restricted to GPU jobs"
    )
    comment: Optional[StrictStr] = Field(default=None, description="Arbitrary comment")
    reason: Optional[StrictStr] = Field(
        default=None,
        description='Describes why the node is in a "DOWN", "DRAINED", "DRAINING", "FAILING" or "FAIL" state',
    )
    reason_changed_at: Optional[V0042Uint64NoValStruct] = None
    reason_set_by_user: Optional[StrictStr] = Field(
        default=None, description="User who set the reason"
    )
    resume_after: Optional[V0042Uint64NoValStruct] = None
    reservation: Optional[StrictStr] = Field(
        default=None, description="Name of reservation containing this node"
    )
    alloc_memory: Optional[StrictInt] = Field(
        default=None, description="Total memory in MB currently allocated for jobs"
    )
    alloc_cpus: Optional[StrictInt] = Field(
        default=None, description="Total number of CPUs currently allocated for jobs"
    )
    alloc_idle_cpus: Optional[StrictInt] = Field(
        default=None, description="Total number of idle CPUs"
    )
    tres_used: Optional[StrictStr] = Field(
        default=None, description="Trackable resources currently allocated for jobs"
    )
    tres_weighted: Optional[Union[StrictFloat, StrictInt]] = Field(
        default=None,
        description="Weighted number of billable trackable resources allocated",
    )
    slurmd_start_time: Optional[V0042Uint64NoValStruct] = None
    sockets: Optional[StrictInt] = Field(
        default=None,
        description="Number of physical processor sockets/chips on the node",
    )
    threads: Optional[StrictInt] = Field(
        default=None, description="Number of logical threads in a single physical core"
    )
    temporary_disk: Optional[StrictInt] = Field(
        default=None, description="Total size in MB of temporary disk storage in TmpFS"
    )
    weight: Optional[StrictInt] = Field(
        default=None, description="Weight of the node for scheduling purposes"
    )
    tres: Optional[StrictStr] = Field(
        default=None, description="Configured trackable resources"
    )
    version: Optional[StrictStr] = Field(default=None, description="Slurmd version")
    __properties: ClassVar[List[str]] = [
        "architecture",
        "burstbuffer_network_address",
        "boards",
        "boot_time",
        "cluster_name",
        "cores",
        "specialized_cores",
        "cpu_binding",
        "cpu_load",
        "free_mem",
        "cpus",
        "effective_cpus",
        "specialized_cpus",
        "energy",
        "external_sensors",
        "extra",
        "power",
        "features",
        "active_features",
        "gpu_spec",
        "gres",
        "gres_drained",
        "gres_used",
        "instance_id",
        "instance_type",
        "last_busy",
        "mcs_label",
        "specialized_memory",
        "name",
        "next_state_after_reboot",
        "address",
        "hostname",
        "state",
        "operating_system",
        "owner",
        "partitions",
        "port",
        "real_memory",
        "res_cores_per_gpu",
        "comment",
        "reason",
        "reason_changed_at",
        "reason_set_by_user",
        "resume_after",
        "reservation",
        "alloc_memory",
        "alloc_cpus",
        "alloc_idle_cpus",
        "tres_used",
        "tres_weighted",
        "slurmd_start_time",
        "sockets",
        "threads",
        "temporary_disk",
        "weight",
        "tres",
        "version",
    ]

    @field_validator("next_state_after_reboot")
    def next_state_after_reboot_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(
                [
                    "INVALID",
                    "UNKNOWN",
                    "DOWN",
                    "IDLE",
                    "ALLOCATED",
                    "ERROR",
                    "MIXED",
                    "FUTURE",
                    "RESERVED",
                    "UNDRAIN",
                    "CLOUD",
                    "RESUME",
                    "DRAIN",
                    "COMPLETING",
                    "NOT_RESPONDING",
                    "POWERED_DOWN",
                    "FAIL",
                    "POWERING_UP",
                    "MAINTENANCE",
                    "REBOOT_REQUESTED",
                    "REBOOT_CANCELED",
                    "POWERING_DOWN",
                    "DYNAMIC_FUTURE",
                    "REBOOT_ISSUED",
                    "PLANNED",
                    "INVALID_REG",
                    "POWER_DOWN",
                    "POWER_UP",
                    "POWER_DRAIN",
                    "DYNAMIC_NORM",
                ]
            ):
                raise ValueError(
                    "each list item must be one of ('INVALID', 'UNKNOWN', 'DOWN', 'IDLE', 'ALLOCATED', 'ERROR', 'MIXED', 'FUTURE', 'RESERVED', 'UNDRAIN', 'CLOUD', 'RESUME', 'DRAIN', 'COMPLETING', 'NOT_RESPONDING', 'POWERED_DOWN', 'FAIL', 'POWERING_UP', 'MAINTENANCE', 'REBOOT_REQUESTED', 'REBOOT_CANCELED', 'POWERING_DOWN', 'DYNAMIC_FUTURE', 'REBOOT_ISSUED', 'PLANNED', 'INVALID_REG', 'POWER_DOWN', 'POWER_UP', 'POWER_DRAIN', 'DYNAMIC_NORM')"
                )
        return value

    @field_validator("state")
    def state_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(
                [
                    "INVALID",
                    "UNKNOWN",
                    "DOWN",
                    "IDLE",
                    "ALLOCATED",
                    "ERROR",
                    "MIXED",
                    "FUTURE",
                    "RESERVED",
                    "UNDRAIN",
                    "CLOUD",
                    "RESUME",
                    "DRAIN",
                    "COMPLETING",
                    "NOT_RESPONDING",
                    "POWERED_DOWN",
                    "FAIL",
                    "POWERING_UP",
                    "MAINTENANCE",
                    "REBOOT_REQUESTED",
                    "REBOOT_CANCELED",
                    "POWERING_DOWN",
                    "DYNAMIC_FUTURE",
                    "REBOOT_ISSUED",
                    "PLANNED",
                    "INVALID_REG",
                    "POWER_DOWN",
                    "POWER_UP",
                    "POWER_DRAIN",
                    "DYNAMIC_NORM",
                ]
            ):
                raise ValueError(
                    "each list item must be one of ('INVALID', 'UNKNOWN', 'DOWN', 'IDLE', 'ALLOCATED', 'ERROR', 'MIXED', 'FUTURE', 'RESERVED', 'UNDRAIN', 'CLOUD', 'RESUME', 'DRAIN', 'COMPLETING', 'NOT_RESPONDING', 'POWERED_DOWN', 'FAIL', 'POWERING_UP', 'MAINTENANCE', 'REBOOT_REQUESTED', 'REBOOT_CANCELED', 'POWERING_DOWN', 'DYNAMIC_FUTURE', 'REBOOT_ISSUED', 'PLANNED', 'INVALID_REG', 'POWER_DOWN', 'POWER_UP', 'POWER_DRAIN', 'DYNAMIC_NORM')"
                )
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V0042Node from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of boot_time
        if self.boot_time:
            _dict["boot_time"] = self.boot_time.to_dict()
        # override the default output from pydantic by calling `to_dict()` of free_mem
        if self.free_mem:
            _dict["free_mem"] = self.free_mem.to_dict()
        # override the default output from pydantic by calling `to_dict()` of energy
        if self.energy:
            _dict["energy"] = self.energy.to_dict()
        # override the default output from pydantic by calling `to_dict()` of last_busy
        if self.last_busy:
            _dict["last_busy"] = self.last_busy.to_dict()
        # override the default output from pydantic by calling `to_dict()` of reason_changed_at
        if self.reason_changed_at:
            _dict["reason_changed_at"] = self.reason_changed_at.to_dict()
        # override the default output from pydantic by calling `to_dict()` of resume_after
        if self.resume_after:
            _dict["resume_after"] = self.resume_after.to_dict()
        # override the default output from pydantic by calling `to_dict()` of slurmd_start_time
        if self.slurmd_start_time:
            _dict["slurmd_start_time"] = self.slurmd_start_time.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V0042Node from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "architecture": obj.get("architecture"),
                "burstbuffer_network_address": obj.get("burstbuffer_network_address"),
                "boards": obj.get("boards"),
                "boot_time": V0042Uint64NoValStruct.from_dict(obj["boot_time"])
                if obj.get("boot_time") is not None
                else None,
                "cluster_name": obj.get("cluster_name"),
                "cores": obj.get("cores"),
                "specialized_cores": obj.get("specialized_cores"),
                "cpu_binding": obj.get("cpu_binding"),
                "cpu_load": obj.get("cpu_load"),
                "free_mem": V0042Uint64NoValStruct.from_dict(obj["free_mem"])
                if obj.get("free_mem") is not None
                else None,
                "cpus": obj.get("cpus"),
                "effective_cpus": obj.get("effective_cpus"),
                "specialized_cpus": obj.get("specialized_cpus"),
                "energy": V0042AcctGatherEnergy.from_dict(obj["energy"])
                if obj.get("energy") is not None
                else None,
                "external_sensors": obj.get("external_sensors"),
                "extra": obj.get("extra"),
                "power": obj.get("power"),
                "features": obj.get("features"),
                "active_features": obj.get("active_features"),
                "gpu_spec": obj.get("gpu_spec"),
                "gres": obj.get("gres"),
                "gres_drained": obj.get("gres_drained"),
                "gres_used": obj.get("gres_used"),
                "instance_id": obj.get("instance_id"),
                "instance_type": obj.get("instance_type"),
                "last_busy": V0042Uint64NoValStruct.from_dict(obj["last_busy"])
                if obj.get("last_busy") is not None
                else None,
                "mcs_label": obj.get("mcs_label"),
                "specialized_memory": obj.get("specialized_memory"),
                "name": obj.get("name"),
                "next_state_after_reboot": obj.get("next_state_after_reboot"),
                "address": obj.get("address"),
                "hostname": obj.get("hostname"),
                "state": obj.get("state"),
                "operating_system": obj.get("operating_system"),
                "owner": obj.get("owner"),
                "partitions": obj.get("partitions"),
                "port": obj.get("port"),
                "real_memory": obj.get("real_memory"),
                "res_cores_per_gpu": obj.get("res_cores_per_gpu"),
                "comment": obj.get("comment"),
                "reason": obj.get("reason"),
                "reason_changed_at": V0042Uint64NoValStruct.from_dict(
                    obj["reason_changed_at"]
                )
                if obj.get("reason_changed_at") is not None
                else None,
                "reason_set_by_user": obj.get("reason_set_by_user"),
                "resume_after": V0042Uint64NoValStruct.from_dict(obj["resume_after"])
                if obj.get("resume_after") is not None
                else None,
                "reservation": obj.get("reservation"),
                "alloc_memory": obj.get("alloc_memory"),
                "alloc_cpus": obj.get("alloc_cpus"),
                "alloc_idle_cpus": obj.get("alloc_idle_cpus"),
                "tres_used": obj.get("tres_used"),
                "tres_weighted": obj.get("tres_weighted"),
                "slurmd_start_time": V0042Uint64NoValStruct.from_dict(
                    obj["slurmd_start_time"]
                )
                if obj.get("slurmd_start_time") is not None
                else None,
                "sockets": obj.get("sockets"),
                "threads": obj.get("threads"),
                "temporary_disk": obj.get("temporary_disk"),
                "weight": obj.get("weight"),
                "tres": obj.get("tres"),
                "version": obj.get("version"),
            }
        )
        return _obj



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0042_user import V0042User


class TestV0042User(unittest.TestCase):
    """V0042User unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0042User:
        """Test V0042User
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0042User`
        """
        model = V0042User()
        if include_optional:
            return V0042User(
                administrator_level = [
                    'Not Set'
                    ],
                associations = [
                    slurmrestpy.models.v0/0/42_assoc_short.v0.0.42_assoc_short(
                        account = '',
                        cluster = '',
                        partition = '',
                        user = '',
                        id = 56, )
                    ],
                coordinators = [
                    slurmrestpy.models.v0/0/42_coord.v0.0.42_coord(
                        name = '',
                        direct = True, )
                    ],
                default = slurmrestpy.models.v0_0_42_user_default.v0_0_42_user_default(
                    account = '',
                    wckey = '', ),
                flags = [
                    'NONE'
                    ],
                name = '',
                old_name = '',
                wckeys = [
                    slurmrestpy.models.v0/0/42_wckey.v0.0.42_wckey(
                        accounting = [
                            slurmrestpy.models.v0/0/42_accounting.v0.0.42_accounting(
                                allocated = slurmrestpy.models.v0_0_42_accounting_allocated.v0_0_42_accounting_allocated(
                                    seconds = 56, ),
                                id = 56,
                                id_alt = 56,
                                start = 56,
                                tres = slurmrestpy.models.v0/0/42_tres.v0.0.42_tres(
                                    type = '',
                                    name = '',
                                    id = 56,
                                    count = 56, ), )
                            ],
                        cluster = '',
                        id = 56,
                        name = '',
                        user = '',
                        flags = [
                            'DELETED'
                            ], )
                    ]
            )
        else:
            return V0042User(
                name = '',
        )
        """

    def testV0042User(self):
        """Test V0042User"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0040_job import V0040Job


class TestV0040Job(unittest.TestCase):
    """V0040Job unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0040Job:
        """Test V0040Job
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0040Job`
        """
        model = V0040Job()
        if include_optional:
            return V0040Job(
                account = '',
                comment = slurmrestpy.models.v0_0_42_job_comment.v0_0_42_job_comment(
                    administrator = '',
                    job = '',
                    system = '', ),
                allocation_nodes = 56,
                array = slurmrestpy.models.v0_0_40_job_array.v0_0_40_job_array(
                    job_id = 56,
                    limits = slurmrestpy.models.v0_0_42_job_array_limits.v0_0_42_job_array_limits(
                        max = slurmrestpy.models.v0_0_42_job_array_limits_max.v0_0_42_job_array_limits_max(
                            running = slurmrestpy.models.v0_0_42_job_array_limits_max_running.v0_0_42_job_array_limits_max_running(
                                tasks = 56, ), ), ),
                    task_id = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    task = '', ),
                association = slurmrestpy.models.v0/0/40_assoc_short.v0.0.40_assoc_short(
                    account = '',
                    cluster = '',
                    partition = '',
                    user = '',
                    id = 56, ),
                block = '',
                cluster = '',
                constraints = '',
                container = '',
                derived_exit_code = slurmrestpy.models.v0/0/40_process_exit_code_verbose.v0.0.40_process_exit_code_verbose(
                    status = [
                        'INVALID'
                        ],
                    return_code = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    signal = slurmrestpy.models.v0_0_40_process_exit_code_verbose_signal.v0_0_40_process_exit_code_verbose_signal(
                        id = slurmrestpy.models.v0/0/40_uint16_no_val.v0.0.40_uint16_no_val(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        name = '', ), ),
                time = slurmrestpy.models.v0_0_40_job_time.v0_0_40_job_time(
                    elapsed = 56,
                    eligible = 56,
                    end = 56,
                    start = 56,
                    submission = 56,
                    suspended = 56,
                    system = slurmrestpy.models.v0_0_42_job_time_system.v0_0_42_job_time_system(
                        seconds = 56,
                        microseconds = 56, ),
                    limit = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    total = slurmrestpy.models.v0_0_42_job_time_total.v0_0_42_job_time_total(
                        seconds = 56,
                        microseconds = 56, ),
                    user = slurmrestpy.models.v0_0_42_job_time_user.v0_0_42_job_time_user(
                        seconds = 56,
                        microseconds = 56, ), ),
                exit_code = slurmrestpy.models.v0/0/40_process_exit_code_verbose.v0.0.40_process_exit_code_verbose(
                    status = [
                        'INVALID'
                        ],
                    return_code = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    signal = slurmrestpy.models.v0_0_40_process_exit_code_verbose_signal.v0_0_40_process_exit_code_verbose_signal(
                        id = slurmrestpy.models.v0/0/40_uint16_no_val.v0.0.40_uint16_no_val(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        name = '', ), ),
                extra = '',
                failed_node = '',
                flags = [
                    'NONE'
                    ],
                group = '',
                het = slurmrestpy.models.v0_0_40_job_het.v0_0_40_job_het(
                    job_id = 56,
                    job_offset = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                        set = True,
                        infinite = True,
                        number = 56, ), ),
                job_id = 56,
                name = '',
                licenses = '',
                mcs = slurmrestpy.models.v0_0_42_job_mcs.v0_0_42_job_mcs(
                    label = '', ),
                nodes = '',
                partition = '',
                hold = True,
                priority = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                qos = '',
                required = slurmrestpy.models.v0_0_40_job_required.v0_0_40_job_required(
                    cpus = 56,
                    memory_per_cpu = slurmrestpy.models.v0/0/40_uint64_no_val.v0.0.40_uint64_no_val(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    memory_per_node = slurmrestpy.models.v0/0/40_uint64_no_val.v0.0.40_uint64_no_val(
                        set = True,
                        infinite = True,
                        number = 56, ), ),
                kill_request_user = '',
                reservation = slurmrestpy.models.v0_0_42_job_reservation.v0_0_42_job_reservation(
                    id = 56,
                    name = '', ),
                script = '',
                state = slurmrestpy.models.v0_0_40_job_state.v0_0_40_job_state(
                    current = [
                        'PENDING'
                        ],
                    reason = '', ),
                steps = [
                    slurmrestpy.models.v0/0/40_step.v0.0.40_step(
                        time = slurmrestpy.models.v0_0_40_step_time.v0_0_40_step_time(
                            elapsed = 56,
                            end = slurmrestpy.models.v0/0/40_uint64_no_val.v0.0.40_uint64_no_val(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            start = slurmrestpy.models.v0/0/40_uint64_no_val.v0.0.40_uint64_no_val(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            suspended = 56,
                            system = slurmrestpy.models.v0_0_42_step_time_system.v0_0_42_step_time_system(
                                seconds = 56,
                                microseconds = 56, ),
                            total = slurmrestpy.models.v0_0_42_step_time_total.v0_0_42_step_time_total(
                                seconds = 56,
                                microseconds = 56, ),
                            user = slurmrestpy.models.v0_0_42_step_time_user.v0_0_42_step_time_user(
                                seconds = 56,
                                microseconds = 56, ), ),
                        exit_code = slurmrestpy.models.v0/0/40_process_exit_code_verbose.v0.0.40_process_exit_code_verbose(
                            status = [
                                'INVALID'
                                ],
                            return_code = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            signal = slurmrestpy.models.v0_0_40_process_exit_code_verbose_signal.v0_0_40_process_exit_code_verbose_signal(
                                id = slurmrestpy.models.v0/0/40_uint16_no_val.v0.0.40_uint16_no_val(
                                    set = True,
                                    infinite = True,
                                    number = 56, ),
                                name = '', ), ),
                        nodes = slurmrestpy.models.v0_0_40_step_nodes.v0_0_40_step_nodes(
                            count = 56,
                            range = '',
                            list = [
                                ''
                                ], ),
                        tasks = slurmrestpy.models.v0_0_42_step_tasks.v0_0_42_step_tasks(
                            count = 56, ),
                        pid = '',
                        cpu = slurmrestpy.models.v0_0_40_step_cpu.v0_0_40_step_CPU(
                            requested_frequency = slurmrestpy.models.v0_0_40_step_cpu_requested_frequency.v0_0_40_step_CPU_requested_frequency(
                                min = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                                    set = True,
                                    infinite = True,
                                    number = 56, ),
                                max = , ),
                            governor = '', ),
                        kill_request_user = '',
                        state = [
                            'PENDING'
                            ],
                        statistics = slurmrestpy.models.v0_0_40_step_statistics.v0_0_40_step_statistics(
                            energy = slurmrestpy.models.v0_0_40_step_statistics_energy.v0_0_40_step_statistics_energy(
                                consumed = , ), ),
                        step = slurmrestpy.models.v0_0_40_step_step.v0_0_40_step_step(
                            name = '', ),
                        task = slurmrestpy.models.v0_0_42_step_task.v0_0_42_step_task(
                            distribution = '', ),
                        tres = slurmrestpy.models.v0_0_40_step_tres.v0_0_40_step_tres(
                            requested = slurmrestpy.models.v0_0_40_step_tres_requested.v0_0_40_step_tres_requested(
                                average = [
                                    slurmrestpy.models.v0/0/40_tres.v0.0.40_tres(
                                        type = '',
                                        name = '',
                                        count = 56, )
                                    ], ),
                            allocated = [
                                slurmrestpy.models.v0/0/40_tres.v0.0.40_tres(
                                    type = '',
                                    name = '',
                                    count = 56, )
                                ], ), )
                    ],
                submit_line = '',
                tres = slurmrestpy.models.v0_0_40_job_tres.v0_0_40_job_tres(
                    allocated = [
                        slurmrestpy.models.v0/0/40_tres.v0.0.40_tres(
                            type = '',
                            name = '',
                            id = 56,
                            count = 56, )
                        ],
                    requested = [
                        slurmrestpy.models.v0/0/40_tres.v0.0.40_tres(
                            type = '',
                            name = '',
                            id = 56,
                            count = 56, )
                        ], ),
                used_gres = '',
                user = '',
                wckey = slurmrestpy.models.v0/0/40_wckey_tag_struct.v0.0.40_wckey_tag_struct(
                    wckey = '',
                    flags = [
                        'ASSIGNED_DEFAULT'
                        ], ),
                working_directory = ''
            )
        else:
            return V0040Job(
        )
        """

    def testV0040Job(self):
        """Test V0040Job"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_users_add_cond_resp_association_condition import (
    V0041OpenapiUsersAddCondRespAssociationCondition,
)


class TestV0041OpenapiUsersAddCondRespAssociationCondition(unittest.TestCase):
    """V0041OpenapiUsersAddCondRespAssociationCondition unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(
        self, include_optional
    ) -> V0041OpenapiUsersAddCondRespAssociationCondition:
        """Test V0041OpenapiUsersAddCondRespAssociationCondition
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiUsersAddCondRespAssociationCondition`
        """
        model = V0041OpenapiUsersAddCondRespAssociationCondition()
        if include_optional:
            return V0041OpenapiUsersAddCondRespAssociationCondition(
                accounts = [
                    ''
                    ],
                association = slurmrestpy.models.v0_0_41_openapi_users_add_cond_resp_association_condition_association.v0_0_41_openapi_users_add_cond_resp_association_condition_association(
                    comment = '',
                    defaultqos = '',
                    grpjobs = slurmrestpy.models.v0_0_41_openapi_users_add_cond_resp_association_condition_association_grpjobs.v0_0_41_openapi_users_add_cond_resp_association_condition_association_grpjobs(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    grpjobsaccrue = slurmrestpy.models.v0_0_41_openapi_users_add_cond_resp_association_condition_association_grpjobsaccrue.v0_0_41_openapi_users_add_cond_resp_association_condition_association_grpjobsaccrue(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    grpsubmitjobs = slurmrestpy.models.v0_0_41_openapi_users_add_cond_resp_association_condition_association_grpsubmitjobs.v0_0_41_openapi_users_add_cond_resp_association_condition_association_grpsubmitjobs(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    grptres = [
                        slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                            type = '',
                            name = '',
                            id = 56,
                            count = 56, )
                        ],
                    grptresmins = [
                        slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                            type = '',
                            name = '',
                            id = 56,
                            count = 56, )
                        ],
                    grptresrunmins = [

                        ],
                    grpwall = slurmrestpy.models.v0_0_41_openapi_users_add_cond_resp_association_condition_association_grpwall.v0_0_41_openapi_users_add_cond_resp_association_condition_association_grpwall(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    maxjobs = slurmrestpy.models.v0_0_41_openapi_users_add_cond_resp_association_condition_association_maxjobs.v0_0_41_openapi_users_add_cond_resp_association_condition_association_maxjobs(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    maxjobsaccrue = slurmrestpy.models.v0_0_41_openapi_users_add_cond_resp_association_condition_association_maxjobsaccrue.v0_0_41_openapi_users_add_cond_resp_association_condition_association_maxjobsaccrue(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    maxsubmitjobs = slurmrestpy.models.v0_0_41_openapi_users_add_cond_resp_association_condition_association_maxsubmitjobs.v0_0_41_openapi_users_add_cond_resp_association_condition_association_maxsubmitjobs(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    maxtresminsperjob = [

                        ],
                    maxtresrunmins = [

                        ],
                    maxtresperjob = [

                        ],
                    maxtrespernode = [

                        ],
                    maxwalldurationperjob = slurmrestpy.models.v0_0_41_openapi_users_add_cond_resp_association_condition_association_maxwalldurationperjob.v0_0_41_openapi_users_add_cond_resp_association_condition_association_maxwalldurationperjob(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    minpriothresh = slurmrestpy.models.v0_0_41_openapi_users_add_cond_resp_association_condition_association_minpriothresh.v0_0_41_openapi_users_add_cond_resp_association_condition_association_minpriothresh(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    parent = '',
                    priority = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_priority.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_priority(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    qoslevel = [
                        ''
                        ],
                    fairshare = 56, ),
                clusters = [
                    ''
                    ],
                partitions = [
                    ''
                    ],
                users = [
                    ''
                    ],
                wckeys = [
                    ''
                    ]
            )
        else:
            return V0041OpenapiUsersAddCondRespAssociationCondition(
                users = [
                    ''
                    ],
        )
        """

    def testV0041OpenapiUsersAddCondRespAssociationCondition(self):
        """Test V0041OpenapiUsersAddCondRespAssociationCondition"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing_extensions import Self

from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_job_resources_nodes import (
    V0041OpenapiJobInfoRespJobsInnerJobResourcesNodes,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_job_resources_threads_per_core import (
    V0041OpenapiJobInfoRespJobsInnerJobResourcesThreadsPerCore,
)


class V0041OpenapiJobInfoRespJobsInnerJobResources(BaseModel):
    """
    Resources used by the job
    """  # noqa: E501

    select_type: List[StrictStr] = Field(
        description="Scheduler consumable resource selection type"
    )
    nodes: Optional[V0041OpenapiJobInfoRespJobsInnerJobResourcesNodes] = None
    cpus: StrictInt = Field(description="Number of allocated CPUs")
    threads_per_core: V0041OpenapiJobInfoRespJobsInnerJobResourcesThreadsPerCore
    __properties: ClassVar[List[str]] = [
        "select_type",
        "nodes",
        "cpus",
        "threads_per_core",
    ]

    @field_validator("select_type")
    def select_type_validate_enum(cls, value):
        """Validates the enum"""
        for i in value:
            if i not in set(
                [
                    "CPU",
                    "SOCKET",
                    "CORE",
                    "BOARD",
                    "MEMORY",
                    "ONE_TASK_PER_CORE",
                    "PACK_NODES",
                    "CORE_DEFAULT_DIST_BLOCK",
                    "LLN",
                    "LINEAR",
                ]
            ):
                raise ValueError(
                    "each list item must be one of ('CPU', 'SOCKET', 'CORE', 'BOARD', 'MEMORY', 'ONE_TASK_PER_CORE', 'PACK_NODES', 'CORE_DEFAULT_DIST_BLOCK', 'LLN', 'LINEAR')"
                )
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V0041OpenapiJobInfoRespJobsInnerJobResources from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of nodes
        if self.nodes:
            _dict["nodes"] = self.nodes.to_dict()
        # override the default output from pydantic by calling `to_dict()` of threads_per_core
        if self.threads_per_core:
            _dict["threads_per_core"] = self.threads_per_core.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V0041OpenapiJobInfoRespJobsInnerJobResources from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "select_type": obj.get("select_type"),
                "nodes": V0041OpenapiJobInfoRespJobsInnerJobResourcesNodes.from_dict(
                    obj["nodes"]
                )
                if obj.get("nodes") is not None
                else None,
                "cpus": obj.get("cpus"),
                "threads_per_core": V0041OpenapiJobInfoRespJobsInnerJobResourcesThreadsPerCore.from_dict(
                    obj["threads_per_core"]
                )
                if obj.get("threads_per_core") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_job_alloc_req import V0041JobAllocReq


class TestV0041JobAllocReq(unittest.TestCase):
    """V0041JobAllocReq unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0041JobAllocReq:
        """Test V0041JobAllocReq
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041JobAllocReq`
        """
        model = V0041JobAllocReq()
        if include_optional:
            return V0041JobAllocReq(
                hetjob = [
                    slurmrestpy.models.v0/0/41_job_desc_msg.v0.0.41_job_desc_msg(
                        account = '',
                        account_gather_frequency = '',
                        admin_comment = '',
                        allocation_node_list = '',
                        allocation_node_port = 56,
                        argv = [
                            ''
                            ],
                        array = '',
                        batch_features = '',
                        begin_time = slurmrestpy.models.v0_0_41_job_desc_msg_begin_time.v0_0_41_job_desc_msg_begin_time(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        flags = [
                            'KILL_INVALID_DEPENDENCY'
                            ],
                        burst_buffer = '',
                        clusters = '',
                        cluster_constraint = '',
                        comment = '',
                        contiguous = True,
                        container = '',
                        container_id = '',
                        core_specification = 56,
                        thread_specification = 56,
                        cpu_binding = '',
                        cpu_binding_flags = [
                            'CPU_BIND_TO_THREADS'
                            ],
                        cpu_frequency = '',
                        cpus_per_tres = '',
                        crontab = slurmrestpy.models.v0_0_41_job_desc_msg_crontab.v0_0_41_job_desc_msg_crontab(
                            minute = '',
                            hour = '',
                            day_of_month = '',
                            month = '',
                            day_of_week = '',
                            specification = '',
                            command = '',
                            line = slurmrestpy.models.v0_0_42_cron_entry_line.v0_0_42_cron_entry_line(
                                start = 56,
                                end = 56, ), ),
                        deadline = 56,
                        delay_boot = 56,
                        dependency = '',
                        end_time = 56,
                        environment = [
                            ''
                            ],
                        rlimits = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits.v0_0_41_job_desc_msg_rlimits(
                            cpu = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_cpu.v0_0_41_job_desc_msg_rlimits_cpu(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            fsize = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_fsize.v0_0_41_job_desc_msg_rlimits_fsize(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            data = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_data.v0_0_41_job_desc_msg_rlimits_data(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            stack = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_stack.v0_0_41_job_desc_msg_rlimits_stack(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            core = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_core.v0_0_41_job_desc_msg_rlimits_core(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            rss = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_rss.v0_0_41_job_desc_msg_rlimits_rss(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            nproc = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_nproc.v0_0_41_job_desc_msg_rlimits_nproc(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            nofile = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_nofile.v0_0_41_job_desc_msg_rlimits_nofile(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            memlock = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_memlock.v0_0_41_job_desc_msg_rlimits_memlock(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            as = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_as.v0_0_41_job_desc_msg_rlimits_as(
                                set = True,
                                infinite = True,
                                number = 56, ), ),
                        excluded_nodes = [
                            ''
                            ],
                        extra = '',
                        constraints = '',
                        group_id = '',
                        hetjob_group = 56,
                        immediate = True,
                        job_id = 56,
                        kill_on_node_fail = True,
                        licenses = '',
                        mail_type = [
                            'BEGIN'
                            ],
                        mail_user = '',
                        mcs_label = '',
                        memory_binding = '',
                        memory_binding_type = [
                            'NONE'
                            ],
                        memory_per_tres = '',
                        name = '',
                        network = '',
                        nice = 56,
                        tasks = 56,
                        open_mode = [
                            'APPEND'
                            ],
                        reserve_ports = 56,
                        overcommit = True,
                        partition = '',
                        distribution_plane_size = slurmrestpy.models.v0_0_41_job_desc_msg_distribution_plane_size.v0_0_41_job_desc_msg_distribution_plane_size(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        power_flags = [
                            null
                            ],
                        prefer = '',
                        hold = True,
                        priority = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_priority.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_priority(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        profile = [
                            'NOT_SET'
                            ],
                        qos = '',
                        reboot = True,
                        required_nodes = [
                            ''
                            ],
                        requeue = True,
                        reservation = '',
                        resv_mpi_ports = 56,
                        script = '',
                        shared = [
                            'none'
                            ],
                        exclusive = [
                            'true'
                            ],
                        oversubscribe = True,
                        site_factor = 56,
                        spank_environment = [
                            ''
                            ],
                        distribution = '',
                        time_limit = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_time_limit.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_time_limit(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        time_minimum = slurmrestpy.models.v0_0_41_job_desc_msg_time_minimum.v0_0_41_job_desc_msg_time_minimum(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        tres_bind = '',
                        tres_freq = '',
                        tres_per_job = '',
                        tres_per_node = '',
                        tres_per_socket = '',
                        tres_per_task = '',
                        user_id = '',
                        wait_all_nodes = True,
                        kill_warning_flags = [
                            'BATCH_JOB'
                            ],
                        kill_warning_signal = '',
                        kill_warning_delay = slurmrestpy.models.v0_0_41_job_desc_msg_kill_warning_delay.v0_0_41_job_desc_msg_kill_warning_delay(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        current_working_directory = '',
                        cpus_per_task = 56,
                        minimum_cpus = 56,
                        maximum_cpus = 56,
                        nodes = '',
                        minimum_nodes = 56,
                        maximum_nodes = 56,
                        minimum_boards_per_node = 56,
                        minimum_sockets_per_board = 56,
                        sockets_per_node = 56,
                        threads_per_core = 56,
                        tasks_per_node = 56,
                        tasks_per_socket = 56,
                        tasks_per_core = 56,
                        tasks_per_board = 56,
                        ntasks_per_tres = 56,
                        minimum_cpus_per_node = 56,
                        memory_per_cpu = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_cpu.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_cpu(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        memory_per_node = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_cpu.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_cpu(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        temporary_disk_per_node = 56,
                        selinux_context = '',
                        required_switches = slurmrestpy.models.v0_0_41_job_desc_msg_required_switches.v0_0_41_job_desc_msg_required_switches(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        segment_size = slurmrestpy.models.v0_0_41_job_desc_msg_segment_size.v0_0_41_job_desc_msg_segment_size(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        standard_error = '',
                        standard_input = '',
                        standard_output = '',
                        wait_for_switch = 56,
                        wckey = '',
                        x11 = [
                            'FORWARD_ALL_NODES'
                            ],
                        x11_magic_cookie = '',
                        x11_target_host = '',
                        x11_target_port = 56, )
                    ],
                job = slurmrestpy.models.v0/0/41_job_desc_msg.v0.0.41_job_desc_msg(
                    account = '',
                    account_gather_frequency = '',
                    admin_comment = '',
                    allocation_node_list = '',
                    allocation_node_port = 56,
                    argv = [
                        ''
                        ],
                    array = '',
                    batch_features = '',
                    begin_time = slurmrestpy.models.v0_0_41_job_desc_msg_begin_time.v0_0_41_job_desc_msg_begin_time(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    flags = [
                        'KILL_INVALID_DEPENDENCY'
                        ],
                    burst_buffer = '',
                    clusters = '',
                    cluster_constraint = '',
                    comment = '',
                    contiguous = True,
                    container = '',
                    container_id = '',
                    core_specification = 56,
                    thread_specification = 56,
                    cpu_binding = '',
                    cpu_binding_flags = [
                        'CPU_BIND_TO_THREADS'
                        ],
                    cpu_frequency = '',
                    cpus_per_tres = '',
                    crontab = slurmrestpy.models.v0_0_41_job_desc_msg_crontab.v0_0_41_job_desc_msg_crontab(
                        minute = '',
                        hour = '',
                        day_of_month = '',
                        month = '',
                        day_of_week = '',
                        specification = '',
                        command = '',
                        line = slurmrestpy.models.v0_0_42_cron_entry_line.v0_0_42_cron_entry_line(
                            start = 56,
                            end = 56, ), ),
                    deadline = 56,
                    delay_boot = 56,
                    dependency = '',
                    end_time = 56,
                    environment = [
                        ''
                        ],
                    rlimits = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits.v0_0_41_job_desc_msg_rlimits(
                        cpu = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_cpu.v0_0_41_job_desc_msg_rlimits_cpu(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        fsize = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_fsize.v0_0_41_job_desc_msg_rlimits_fsize(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        data = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_data.v0_0_41_job_desc_msg_rlimits_data(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        stack = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_stack.v0_0_41_job_desc_msg_rlimits_stack(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        core = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_core.v0_0_41_job_desc_msg_rlimits_core(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        rss = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_rss.v0_0_41_job_desc_msg_rlimits_rss(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        nproc = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_nproc.v0_0_41_job_desc_msg_rlimits_nproc(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        nofile = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_nofile.v0_0_41_job_desc_msg_rlimits_nofile(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        memlock = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_memlock.v0_0_41_job_desc_msg_rlimits_memlock(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        as = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_as.v0_0_41_job_desc_msg_rlimits_as(
                            set = True,
                            infinite = True,
                            number = 56, ), ),
                    excluded_nodes = [
                        ''
                        ],
                    extra = '',
                    constraints = '',
                    group_id = '',
                    hetjob_group = 56,
                    immediate = True,
                    job_id = 56,
                    kill_on_node_fail = True,
                    licenses = '',
                    mail_type = [
                        'BEGIN'
                        ],
                    mail_user = '',
                    mcs_label = '',
                    memory_binding = '',
                    memory_binding_type = [
                        'NONE'
                        ],
                    memory_per_tres = '',
                    name = '',
                    network = '',
                    nice = 56,
                    tasks = 56,
                    open_mode = [
                        'APPEND'
                        ],
                    reserve_ports = 56,
                    overcommit = True,
                    partition = '',
                    distribution_plane_size = slurmrestpy.models.v0_0_41_job_desc_msg_distribution_plane_size.v0_0_41_job_desc_msg_distribution_plane_size(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    power_flags = [
                        null
                        ],
                    prefer = '',
                    hold = True,
                    priority = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_priority.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_priority(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    profile = [
                        'NOT_SET'
                        ],
                    qos = '',
                    reboot = True,
                    required_nodes = [
                        ''
                        ],
                    requeue = True,
                    reservation = '',
                    resv_mpi_ports = 56,
                    script = '',
                    shared = [
                        'none'
                        ],
                    exclusive = [
                        'true'
                        ],
                    oversubscribe = True,
                    site_factor = 56,
                    spank_environment = [
                        ''
                        ],
                    distribution = '',
                    time_limit = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_time_limit.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_time_limit(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    time_minimum = slurmrestpy.models.v0_0_41_job_desc_msg_time_minimum.v0_0_41_job_desc_msg_time_minimum(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    tres_bind = '',
                    tres_freq = '',
                    tres_per_job = '',
                    tres_per_node = '',
                    tres_per_socket = '',
                    tres_per_task = '',
                    user_id = '',
                    wait_all_nodes = True,
                    kill_warning_flags = [
                        'BATCH_JOB'
                        ],
                    kill_warning_signal = '',
                    kill_warning_delay = slurmrestpy.models.v0_0_41_job_desc_msg_kill_warning_delay.v0_0_41_job_desc_msg_kill_warning_delay(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    current_working_directory = '',
                    cpus_per_task = 56,
                    minimum_cpus = 56,
                    maximum_cpus = 56,
                    nodes = '',
                    minimum_nodes = 56,
                    maximum_nodes = 56,
                    minimum_boards_per_node = 56,
                    minimum_sockets_per_board = 56,
                    sockets_per_node = 56,
                    threads_per_core = 56,
                    tasks_per_node = 56,
                    tasks_per_socket = 56,
                    tasks_per_core = 56,
                    tasks_per_board = 56,
                    ntasks_per_tres = 56,
                    minimum_cpus_per_node = 56,
                    memory_per_cpu = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_cpu.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_cpu(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    memory_per_node = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_cpu.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_cpu(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    temporary_disk_per_node = 56,
                    selinux_context = '',
                    required_switches = slurmrestpy.models.v0_0_41_job_desc_msg_required_switches.v0_0_41_job_desc_msg_required_switches(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    segment_size = slurmrestpy.models.v0_0_41_job_desc_msg_segment_size.v0_0_41_job_desc_msg_segment_size(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    standard_error = '',
                    standard_input = '',
                    standard_output = '',
                    wait_for_switch = 56,
                    wckey = '',
                    x11 = [
                        'FORWARD_ALL_NODES'
                        ],
                    x11_magic_cookie = '',
                    x11_target_host = '',
                    x11_target_port = 56, )
            )
        else:
            return V0041JobAllocReq(
        )
        """

    def testV0041JobAllocReq(self):
        """Test V0041JobAllocReq"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0040_job_info import V0040JobInfo


class TestV0040JobInfo(unittest.TestCase):
    """V0040JobInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0040JobInfo:
        """Test V0040JobInfo
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0040JobInfo`
        """
        model = V0040JobInfo()
        if include_optional:
            return V0040JobInfo(
                account = '',
                accrue_time = slurmrestpy.models.v0/0/40_uint64_no_val.v0.0.40_uint64_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                admin_comment = '',
                allocating_node = '',
                array_job_id = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                array_task_id = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                array_max_tasks = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                array_task_string = '',
                association_id = 56,
                batch_features = '',
                batch_flag = True,
                batch_host = '',
                flags = [
                    'KILL_INVALID_DEPENDENCY'
                    ],
                burst_buffer = '',
                burst_buffer_state = '',
                cluster = '',
                cluster_features = '',
                command = '',
                comment = '',
                container = '',
                container_id = '',
                contiguous = True,
                core_spec = 56,
                thread_spec = 56,
                cores_per_socket = slurmrestpy.models.v0/0/40_uint16_no_val.v0.0.40_uint16_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                billable_tres = slurmrestpy.models.v0/0/40_float64_no_val.v0.0.40_float64_no_val(
                    set = True,
                    infinite = True,
                    number = 1.337, ),
                cpus_per_task = slurmrestpy.models.v0/0/40_uint16_no_val.v0.0.40_uint16_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                cpu_frequency_minimum = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                cpu_frequency_maximum = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                cpu_frequency_governor = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                cpus_per_tres = '',
                cron = '',
                deadline = slurmrestpy.models.v0/0/40_uint64_no_val.v0.0.40_uint64_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                delay_boot = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                dependency = '',
                derived_exit_code = slurmrestpy.models.v0/0/40_process_exit_code_verbose.v0.0.40_process_exit_code_verbose(
                    status = [
                        'INVALID'
                        ],
                    return_code = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    signal = slurmrestpy.models.v0_0_40_process_exit_code_verbose_signal.v0_0_40_process_exit_code_verbose_signal(
                        id = slurmrestpy.models.v0/0/40_uint16_no_val.v0.0.40_uint16_no_val(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        name = '', ), ),
                eligible_time = slurmrestpy.models.v0/0/40_uint64_no_val.v0.0.40_uint64_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                end_time = slurmrestpy.models.v0/0/40_uint64_no_val.v0.0.40_uint64_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                excluded_nodes = '',
                exit_code = slurmrestpy.models.v0/0/40_process_exit_code_verbose.v0.0.40_process_exit_code_verbose(
                    status = [
                        'INVALID'
                        ],
                    return_code = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    signal = slurmrestpy.models.v0_0_40_process_exit_code_verbose_signal.v0_0_40_process_exit_code_verbose_signal(
                        id = slurmrestpy.models.v0/0/40_uint16_no_val.v0.0.40_uint16_no_val(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        name = '', ), ),
                extra = '',
                failed_node = '',
                features = '',
                federation_origin = '',
                federation_siblings_active = '',
                federation_siblings_viable = '',
                gres_detail = [
                    ''
                    ],
                group_id = 56,
                group_name = '',
                het_job_id = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                het_job_id_set = '',
                het_job_offset = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                job_id = 56,
                job_resources = slurmrestpy.models.v0/0/40_job_res.v0.0.40_job_res(
                    nodes = '',
                    allocated_cores = 56,
                    allocated_cpus = 56,
                    allocated_hosts = 56,
                    allocated_nodes = [
                        null
                        ], ),
                job_size_str = [
                    ''
                    ],
                job_state = [
                    'PENDING'
                    ],
                last_sched_evaluation = slurmrestpy.models.v0/0/40_uint64_no_val.v0.0.40_uint64_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                licenses = '',
                mail_type = [
                    'BEGIN'
                    ],
                mail_user = '',
                max_cpus = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                max_nodes = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                mcs_label = '',
                memory_per_tres = '',
                name = '',
                network = '',
                nodes = '',
                nice = 56,
                tasks_per_core = slurmrestpy.models.v0/0/40_uint16_no_val.v0.0.40_uint16_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                tasks_per_tres = slurmrestpy.models.v0/0/40_uint16_no_val.v0.0.40_uint16_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                tasks_per_node = slurmrestpy.models.v0/0/40_uint16_no_val.v0.0.40_uint16_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                tasks_per_socket = slurmrestpy.models.v0/0/40_uint16_no_val.v0.0.40_uint16_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                tasks_per_board = slurmrestpy.models.v0/0/40_uint16_no_val.v0.0.40_uint16_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                cpus = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                node_count = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                tasks = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                partition = '',
                prefer = '',
                memory_per_cpu = slurmrestpy.models.v0/0/40_uint64_no_val.v0.0.40_uint64_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                memory_per_node = slurmrestpy.models.v0/0/40_uint64_no_val.v0.0.40_uint64_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                minimum_cpus_per_node = slurmrestpy.models.v0/0/40_uint16_no_val.v0.0.40_uint16_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                minimum_tmp_disk_per_node = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                power = slurmrestpy.models.v0_0_40_job_info_power.v0_0_40_job_info_power(
                    flags = [
                        null
                        ], ),
                preempt_time = slurmrestpy.models.v0/0/40_uint64_no_val.v0.0.40_uint64_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                preemptable_time = slurmrestpy.models.v0/0/40_uint64_no_val.v0.0.40_uint64_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                pre_sus_time = slurmrestpy.models.v0/0/40_uint64_no_val.v0.0.40_uint64_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                hold = True,
                priority = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                profile = [
                    'NOT_SET'
                    ],
                qos = '',
                reboot = True,
                required_nodes = '',
                minimum_switches = 56,
                requeue = True,
                resize_time = slurmrestpy.models.v0/0/40_uint64_no_val.v0.0.40_uint64_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                restart_cnt = 56,
                resv_name = '',
                scheduled_nodes = '',
                selinux_context = '',
                shared = [
                    'none'
                    ],
                exclusive = [
                    'true'
                    ],
                oversubscribe = True,
                show_flags = [
                    'ALL'
                    ],
                sockets_per_board = 56,
                sockets_per_node = slurmrestpy.models.v0/0/40_uint16_no_val.v0.0.40_uint16_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                start_time = slurmrestpy.models.v0/0/40_uint64_no_val.v0.0.40_uint64_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                state_description = '',
                state_reason = '',
                standard_error = '',
                standard_input = '',
                standard_output = '',
                submit_time = slurmrestpy.models.v0/0/40_uint64_no_val.v0.0.40_uint64_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                suspend_time = slurmrestpy.models.v0/0/40_uint64_no_val.v0.0.40_uint64_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                system_comment = '',
                time_limit = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                time_minimum = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                threads_per_core = slurmrestpy.models.v0/0/40_uint16_no_val.v0.0.40_uint16_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                tres_bind = '',
                tres_freq = '',
                tres_per_job = '',
                tres_per_node = '',
                tres_per_socket = '',
                tres_per_task = '',
                tres_req_str = '',
                tres_alloc_str = '',
                user_id = 56,
                user_name = '',
                maximum_switch_wait_time = 56,
                wckey = '',
                current_working_directory = ''
            )
        else:
            return V0040JobInfo(
        )
        """

    def testV0040JobInfo(self):
        """Test V0040JobInfo"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing_extensions import Self

from slurmrestpy.models.v0040_tres import V0040Tres
from slurmrestpy.models.v0040_uint32_no_val import V0040Uint32NoVal


class V0040AssocRecSet(BaseModel):
    """
    V0040AssocRecSet
    """  # noqa: E501

    comment: Optional[StrictStr] = Field(default=None, description="Arbitrary comment")
    defaultqos: Optional[StrictStr] = Field(default=None, description="Default QOS")
    grpjobs: Optional[V0040Uint32NoVal] = None
    grpjobsaccrue: Optional[V0040Uint32NoVal] = None
    grpsubmitjobs: Optional[V0040Uint32NoVal] = None
    grptres: Optional[List[V0040Tres]] = None
    grptresmins: Optional[List[V0040Tres]] = None
    grptresrunmins: Optional[List[V0040Tres]] = None
    grpwall: Optional[V0040Uint32NoVal] = None
    maxjobs: Optional[V0040Uint32NoVal] = None
    maxjobsaccrue: Optional[V0040Uint32NoVal] = None
    maxsubmitjobs: Optional[V0040Uint32NoVal] = None
    maxtresminsperjob: Optional[List[V0040Tres]] = None
    maxtresrunmins: Optional[List[V0040Tres]] = None
    maxtresperjob: Optional[List[V0040Tres]] = None
    maxtrespernode: Optional[List[V0040Tres]] = None
    maxwalldurationperjob: Optional[V0040Uint32NoVal] = None
    minpriothresh: Optional[V0040Uint32NoVal] = None
    parent: Optional[StrictStr] = Field(
        default=None, description="Name of parent account"
    )
    priority: Optional[V0040Uint32NoVal] = None
    qoslevel: Optional[List[StrictStr]] = Field(
        default=None, description="List of QOS names"
    )
    fairshare: Optional[StrictInt] = Field(
        default=None, description="Allocated shares used for fairshare calculation"
    )
    __properties: ClassVar[List[str]] = [
        "comment",
        "defaultqos",
        "grpjobs",
        "grpjobsaccrue",
        "grpsubmitjobs",
        "grptres",
        "grptresmins",
        "grptresrunmins",
        "grpwall",
        "maxjobs",
        "maxjobsaccrue",
        "maxsubmitjobs",
        "maxtresminsperjob",
        "maxtresrunmins",
        "maxtresperjob",
        "maxtrespernode",
        "maxwalldurationperjob",
        "minpriothresh",
        "parent",
        "priority",
        "qoslevel",
        "fairshare",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V0040AssocRecSet from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of grpjobs
        if self.grpjobs:
            _dict["grpjobs"] = self.grpjobs.to_dict()
        # override the default output from pydantic by calling `to_dict()` of grpjobsaccrue
        if self.grpjobsaccrue:
            _dict["grpjobsaccrue"] = self.grpjobsaccrue.to_dict()
        # override the default output from pydantic by calling `to_dict()` of grpsubmitjobs
        if self.grpsubmitjobs:
            _dict["grpsubmitjobs"] = self.grpsubmitjobs.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in grptres (list)
        _items = []
        if self.grptres:
            for _item_grptres in self.grptres:
                if _item_grptres:
                    _items.append(_item_grptres.to_dict())
            _dict["grptres"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in grptresmins (list)
        _items = []
        if self.grptresmins:
            for _item_grptresmins in self.grptresmins:
                if _item_grptresmins:
                    _items.append(_item_grptresmins.to_dict())
            _dict["grptresmins"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in grptresrunmins (list)
        _items = []
        if self.grptresrunmins:
            for _item_grptresrunmins in self.grptresrunmins:
                if _item_grptresrunmins:
                    _items.append(_item_grptresrunmins.to_dict())
            _dict["grptresrunmins"] = _items
        # override the default output from pydantic by calling `to_dict()` of grpwall
        if self.grpwall:
            _dict["grpwall"] = self.grpwall.to_dict()
        # override the default output from pydantic by calling `to_dict()` of maxjobs
        if self.maxjobs:
            _dict["maxjobs"] = self.maxjobs.to_dict()
        # override the default output from pydantic by calling `to_dict()` of maxjobsaccrue
        if self.maxjobsaccrue:
            _dict["maxjobsaccrue"] = self.maxjobsaccrue.to_dict()
        # override the default output from pydantic by calling `to_dict()` of maxsubmitjobs
        if self.maxsubmitjobs:
            _dict["maxsubmitjobs"] = self.maxsubmitjobs.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in maxtresminsperjob (list)
        _items = []
        if self.maxtresminsperjob:
            for _item_maxtresminsperjob in self.maxtresminsperjob:
                if _item_maxtresminsperjob:
                    _items.append(_item_maxtresminsperjob.to_dict())
            _dict["maxtresminsperjob"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in maxtresrunmins (list)
        _items = []
        if self.maxtresrunmins:
            for _item_maxtresrunmins in self.maxtresrunmins:
                if _item_maxtresrunmins:
                    _items.append(_item_maxtresrunmins.to_dict())
            _dict["maxtresrunmins"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in maxtresperjob (list)
        _items = []
        if self.maxtresperjob:
            for _item_maxtresperjob in self.maxtresperjob:
                if _item_maxtresperjob:
                    _items.append(_item_maxtresperjob.to_dict())
            _dict["maxtresperjob"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in maxtrespernode (list)
        _items = []
        if self.maxtrespernode:
            for _item_maxtrespernode in self.maxtrespernode:
                if _item_maxtrespernode:
                    _items.append(_item_maxtrespernode.to_dict())
            _dict["maxtrespernode"] = _items
        # override the default output from pydantic by calling `to_dict()` of maxwalldurationperjob
        if self.maxwalldurationperjob:
            _dict["maxwalldurationperjob"] = self.maxwalldurationperjob.to_dict()
        # override the default output from pydantic by calling `to_dict()` of minpriothresh
        if self.minpriothresh:
            _dict["minpriothresh"] = self.minpriothresh.to_dict()
        # override the default output from pydantic by calling `to_dict()` of priority
        if self.priority:
            _dict["priority"] = self.priority.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V0040AssocRecSet from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "comment": obj.get("comment"),
                "defaultqos": obj.get("defaultqos"),
                "grpjobs": V0040Uint32NoVal.from_dict(obj["grpjobs"])
                if obj.get("grpjobs") is not None
                else None,
                "grpjobsaccrue": V0040Uint32NoVal.from_dict(obj["grpjobsaccrue"])
                if obj.get("grpjobsaccrue") is not None
                else None,
                "grpsubmitjobs": V0040Uint32NoVal.from_dict(obj["grpsubmitjobs"])
                if obj.get("grpsubmitjobs") is not None
                else None,
                "grptres": [V0040Tres.from_dict(_item) for _item in obj["grptres"]]
                if obj.get("grptres") is not None
                else None,
                "grptresmins": [
                    V0040Tres.from_dict(_item) for _item in obj["grptresmins"]
                ]
                if obj.get("grptresmins") is not None
                else None,
                "grptresrunmins": [
                    V0040Tres.from_dict(_item) for _item in obj["grptresrunmins"]
                ]
                if obj.get("grptresrunmins") is not None
                else None,
                "grpwall": V0040Uint32NoVal.from_dict(obj["grpwall"])
                if obj.get("grpwall") is not None
                else None,
                "maxjobs": V0040Uint32NoVal.from_dict(obj["maxjobs"])
                if obj.get("maxjobs") is not None
                else None,
                "maxjobsaccrue": V0040Uint32NoVal.from_dict(obj["maxjobsaccrue"])
                if obj.get("maxjobsaccrue") is not None
                else None,
                "maxsubmitjobs": V0040Uint32NoVal.from_dict(obj["maxsubmitjobs"])
                if obj.get("maxsubmitjobs") is not None
                else None,
                "maxtresminsperjob": [
                    V0040Tres.from_dict(_item) for _item in obj["maxtresminsperjob"]
                ]
                if obj.get("maxtresminsperjob") is not None
                else None,
                "maxtresrunmins": [
                    V0040Tres.from_dict(_item) for _item in obj["maxtresrunmins"]
                ]
                if obj.get("maxtresrunmins") is not None
                else None,
                "maxtresperjob": [
                    V0040Tres.from_dict(_item) for _item in obj["maxtresperjob"]
                ]
                if obj.get("maxtresperjob") is not None
                else None,
                "maxtrespernode": [
                    V0040Tres.from_dict(_item) for _item in obj["maxtrespernode"]
                ]
                if obj.get("maxtrespernode") is not None
                else None,
                "maxwalldurationperjob": V0040Uint32NoVal.from_dict(
                    obj["maxwalldurationperjob"]
                )
                if obj.get("maxwalldurationperjob") is not None
                else None,
                "minpriothresh": V0040Uint32NoVal.from_dict(obj["minpriothresh"])
                if obj.get("minpriothresh") is not None
                else None,
                "parent": obj.get("parent"),
                "priority": V0040Uint32NoVal.from_dict(obj["priority"])
                if obj.get("priority") is not None
                else None,
                "qoslevel": obj.get("qoslevel"),
                "fairshare": obj.get("fairshare"),
            }
        )
        return _obj



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0040_qos_limits_max_jobs import V0040QosLimitsMaxJobs


class TestV0040QosLimitsMaxJobs(unittest.TestCase):
    """V0040QosLimitsMaxJobs unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0040QosLimitsMaxJobs:
        """Test V0040QosLimitsMaxJobs
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0040QosLimitsMaxJobs`
        """
        model = V0040QosLimitsMaxJobs()
        if include_optional:
            return V0040QosLimitsMaxJobs(
                active_jobs = slurmrestpy.models.v0_0_40_qos_limits_max_jobs_active_jobs.v0_0_40_qos_limits_max_jobs_active_jobs(
                    per = slurmrestpy.models.v0_0_40_qos_limits_max_jobs_active_jobs_per.v0_0_40_qos_limits_max_jobs_active_jobs_per(
                        account = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        user = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                            set = True,
                            infinite = True,
                            number = 56, ), ), ),
                per = slurmrestpy.models.v0_0_40_qos_limits_max_jobs_active_jobs_per.v0_0_40_qos_limits_max_jobs_active_jobs_per(
                    account = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    user = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                        set = True,
                        infinite = True,
                        number = 56, ), )
            )
        else:
            return V0040QosLimitsMaxJobs(
        )
        """

    def testV0040QosLimitsMaxJobs(self):
        """Test V0040QosLimitsMaxJobs"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0040_openapi_shares_resp import V0040OpenapiSharesResp


class TestV0040OpenapiSharesResp(unittest.TestCase):
    """V0040OpenapiSharesResp unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0040OpenapiSharesResp:
        """Test V0040OpenapiSharesResp
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0040OpenapiSharesResp`
        """
        model = V0040OpenapiSharesResp()
        if include_optional:
            return V0040OpenapiSharesResp(
                shares = slurmrestpy.models.v0/0/40_shares_resp_msg.v0.0.40_shares_resp_msg(
                    shares = [
                        slurmrestpy.models.v0/0/40_assoc_shares_obj_wrap.v0.0.40_assoc_shares_obj_wrap(
                            id = 56,
                            cluster = '',
                            name = '',
                            parent = '',
                            partition = '',
                            shares_normalized = slurmrestpy.models.v0/0/40_float64_no_val.v0.0.40_float64_no_val(
                                set = True,
                                infinite = True,
                                number = 1.337, ),
                            tres = slurmrestpy.models.v0_0_40_assoc_shares_obj_wrap_tres.v0_0_40_assoc_shares_obj_wrap_tres(
                                run_seconds = [
                                    slurmrestpy.models.v0/0/40_shares_uint64_tres.v0.0.40_shares_uint64_tres(
                                        name = '',
                                        value = slurmrestpy.models.v0/0/40_uint64_no_val.v0.0.40_uint64_no_val(
                                            set = True,
                                            infinite = True,
                                            number = 56, ), )
                                    ],
                                group_minutes = [
                                    slurmrestpy.models.v0/0/40_shares_uint64_tres.v0.0.40_shares_uint64_tres(
                                        name = '', )
                                    ],
                                usage = [
                                    slurmrestpy.models.v0/0/40_shares_float128_tres.v0.0.40_shares_float128_tres(
                                        name = '', )
                                    ], ),
                            effective_usage = 1.337,
                            usage_normalized = slurmrestpy.models.v0/0/40_float64_no_val.v0.0.40_float64_no_val(
                                set = True,
                                infinite = True,
                                number = 1.337, ),
                            usage = 56,
                            fairshare = slurmrestpy.models.v0_0_40_assoc_shares_obj_wrap_fairshare.v0_0_40_assoc_shares_obj_wrap_fairshare(
                                factor = 1.337,
                                level = 1.337, ),
                            type = [
                                'USER'
                                ], )
                        ],
                    total_shares = 56, ),
                meta = slurmrestpy.models.v0/0/40_openapi_meta.v0.0.40_openapi_meta(
                    plugin = slurmrestpy.models.v0_0_42_openapi_meta_plugin.v0_0_42_openapi_meta_plugin(
                        type = '',
                        name = '',
                        data_parser = '',
                        accounting_storage = '', ),
                    client = slurmrestpy.models.v0_0_42_openapi_meta_client.v0_0_42_openapi_meta_client(
                        source = '',
                        user = '',
                        group = '', ),
                    command = [
                        ''
                        ],
                    slurm = slurmrestpy.models.v0_0_42_openapi_meta_slurm.v0_0_42_openapi_meta_slurm(
                        version = slurmrestpy.models.v0_0_42_openapi_meta_slurm_version.v0_0_42_openapi_meta_slurm_version(
                            major = '',
                            micro = '',
                            minor = '', ),
                        release = '',
                        cluster = '', ), ),
                errors = [
                    slurmrestpy.models.v0/0/40_openapi_error.v0.0.40_openapi_error(
                        description = '',
                        error_number = 56,
                        error = '',
                        source = '', )
                    ],
                warnings = [
                    slurmrestpy.models.v0/0/40_openapi_warning.v0.0.40_openapi_warning(
                        description = '',
                        source = '', )
                    ]
            )
        else:
            return V0040OpenapiSharesResp(
                shares = slurmrestpy.models.v0/0/40_shares_resp_msg.v0.0.40_shares_resp_msg(
                    shares = [
                        slurmrestpy.models.v0/0/40_assoc_shares_obj_wrap.v0.0.40_assoc_shares_obj_wrap(
                            id = 56,
                            cluster = '',
                            name = '',
                            parent = '',
                            partition = '',
                            shares_normalized = slurmrestpy.models.v0/0/40_float64_no_val.v0.0.40_float64_no_val(
                                set = True,
                                infinite = True,
                                number = 1.337, ),
                            tres = slurmrestpy.models.v0_0_40_assoc_shares_obj_wrap_tres.v0_0_40_assoc_shares_obj_wrap_tres(
                                run_seconds = [
                                    slurmrestpy.models.v0/0/40_shares_uint64_tres.v0.0.40_shares_uint64_tres(
                                        name = '',
                                        value = slurmrestpy.models.v0/0/40_uint64_no_val.v0.0.40_uint64_no_val(
                                            set = True,
                                            infinite = True,
                                            number = 56, ), )
                                    ],
                                group_minutes = [
                                    slurmrestpy.models.v0/0/40_shares_uint64_tres.v0.0.40_shares_uint64_tres(
                                        name = '', )
                                    ],
                                usage = [
                                    slurmrestpy.models.v0/0/40_shares_float128_tres.v0.0.40_shares_float128_tres(
                                        name = '', )
                                    ], ),
                            effective_usage = 1.337,
                            usage_normalized = slurmrestpy.models.v0/0/40_float64_no_val.v0.0.40_float64_no_val(
                                set = True,
                                infinite = True,
                                number = 1.337, ),
                            usage = 56,
                            fairshare = slurmrestpy.models.v0_0_40_assoc_shares_obj_wrap_fairshare.v0_0_40_assoc_shares_obj_wrap_fairshare(
                                factor = 1.337,
                                level = 1.337, ),
                            type = [
                                'USER'
                                ], )
                        ],
                    total_shares = 56, ),
        )
        """

    def testV0040OpenapiSharesResp(self):
        """Test V0040OpenapiSharesResp"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_shares_resp_shares_shares_inner import (
    V0041OpenapiSharesRespSharesSharesInner,
)


class TestV0041OpenapiSharesRespSharesSharesInner(unittest.TestCase):
    """V0041OpenapiSharesRespSharesSharesInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(
        self, include_optional
    ) -> V0041OpenapiSharesRespSharesSharesInner:
        """Test V0041OpenapiSharesRespSharesSharesInner
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiSharesRespSharesSharesInner`
        """
        model = V0041OpenapiSharesRespSharesSharesInner()
        if include_optional:
            return V0041OpenapiSharesRespSharesSharesInner(
                id = 56,
                cluster = '',
                name = '',
                parent = '',
                partition = '',
                shares_normalized = slurmrestpy.models.v0_0_41_openapi_shares_resp_shares_shares_inner_shares_normalized.v0_0_41_openapi_shares_resp_shares_shares_inner_shares_normalized(
                    set = True,
                    infinite = True,
                    number = 1.337, ),
                shares = slurmrestpy.models.v0_0_41_openapi_shares_resp_shares_shares_inner_shares.v0_0_41_openapi_shares_resp_shares_shares_inner_shares(
                    set = True,
                    infinite = True,
                    number = 56, ),
                tres = slurmrestpy.models.v0_0_41_openapi_shares_resp_shares_shares_inner_tres.v0_0_41_openapi_shares_resp_shares_shares_inner_tres(
                    run_seconds = [
                        slurmrestpy.models.v0_0_41_openapi_shares_resp_shares_shares_inner_tres_run_seconds_inner.v0_0_41_openapi_shares_resp_shares_shares_inner_tres_run_seconds_inner(
                            name = '',
                            value = slurmrestpy.models.v0_0_41_openapi_shares_resp_shares_shares_inner_tres_run_seconds_inner_value.v0_0_41_openapi_shares_resp_shares_shares_inner_tres_run_seconds_inner_value(
                                set = True,
                                infinite = True,
                                number = 56, ), )
                        ],
                    group_minutes = [
                        slurmrestpy.models.v0_0_41_openapi_shares_resp_shares_shares_inner_tres_run_seconds_inner.v0_0_41_openapi_shares_resp_shares_shares_inner_tres_run_seconds_inner(
                            name = '', )
                        ],
                    usage = [
                        slurmrestpy.models.v0_0_41_openapi_shares_resp_shares_shares_inner_tres_usage_inner.v0_0_41_openapi_shares_resp_shares_shares_inner_tres_usage_inner(
                            name = '', )
                        ], ),
                effective_usage = 1.337,
                usage_normalized = slurmrestpy.models.v0_0_41_openapi_shares_resp_shares_shares_inner_usage_normalized.v0_0_41_openapi_shares_resp_shares_shares_inner_usage_normalized(
                    set = True,
                    infinite = True,
                    number = 1.337, ),
                usage = 56,
                fairshare = slurmrestpy.models.v0_0_40_assoc_shares_obj_wrap_fairshare.v0_0_40_assoc_shares_obj_wrap_fairshare(
                    factor = 1.337,
                    level = 1.337, ),
                type = [
                    'USER'
                    ]
            )
        else:
            return V0041OpenapiSharesRespSharesSharesInner(
        )
        """

    def testV0041OpenapiSharesRespSharesSharesInner(self):
        """Test V0041OpenapiSharesRespSharesSharesInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
